@@ -2,7 +2,7 @@ from .node import (
     ConfigNode,
     ConfigFlexNode,
     ConfigParam,
-    DictOfConfigNodes
+    OptionalConfigParam
 )
 from .registry import ConfigRegistry
 from .functional import (
@@ -15,3 +15,7 @@ from . import builtin_refs as _builtin_refs
 from .instantiate import instantiate
 from .logging import configure_logging
 from .commandline import cli
+from .experimental import (
+    ConfigParamDictOfConfigNodes,
+    ConfigParamMultiType
+)
\ No newline at end of file
